==> peony_4.10.0.5.orig.tar.gz: peony-4.10.0.5/peony-qt-desktop/desktop-icon-view-delegate.h <==
/*
 * Peony-Qt
 *
 * Copyright (C) 2020, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yue Lan <lanyue@kylinos.cn>
 *
 */

#ifndef DESKTOPICONVIEWDELEGATE_H
#define DESKTOPICONVIEWDELEGATE_H

#include <QStyledItemDelegate>

class QPushButton;

namespace Peony {

class DesktopIconView;

class DesktopIconViewDelegate : public QStyledItemDelegate
{
    Q_OBJECT
public:
    explicit DesktopIconViewDelegate(QObject *parent = nullptr);
    ~DesktopIconViewDelegate() override;

    void initStyleOption(QStyleOptionViewItem *option, const QModelIndex &index) const override {
        return QStyledItemDelegate::initStyleOption(option, index);
    }
    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;

    DesktopIconView *getView() const;

    //初始化option
     void initIndexOption(QStyleOptionViewItem *option,
                          const QModelIndex &index) const;
protected:
    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;

    //edit
    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
    void setEditorData(QWidget *editor, const QModelIndex &index) const override;
    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;

private Q_SLOT:
    void slot_finishEdit();/* 编辑完成 */

private:
    QPushButton *m_styled_button;
};

}

#endif // DESKTOPICONVIEWDELEGATE_H

==> peony_5.0.0.1.orig.tar.gz: peony-5.0.0.1/peony-qt-desktop/desktop-icon-view-delegate.h <==
/*
 * Peony-Qt
 *
 * Copyright (C) 2020, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yue Lan <lanyue@kylinos.cn>
 *
 */

#ifndef DESKTOPICONVIEWDELEGATE_H
#define DESKTOPICONVIEWDELEGATE_H

#include <QStyledItemDelegate>
#include <memory>

class QPushButton;
class AdvancedDesktopIconView;
namespace Peony {
class FileInfo;

class DesktopIconViewDelegate : public QStyledItemDelegate
{
    Q_OBJECT
public:
    explicit DesktopIconViewDelegate(QObject *parent = nullptr);
    ~DesktopIconViewDelegate() override;

    void initStyleOption(QStyleOptionViewItem *option, const QModelIndex &index) const override {
        return QStyledItemDelegate::initStyleOption(option, index);
    }

    AdvancedDesktopIconView *getView() const;

    //初始化option
     void initIndexOption(QStyleOptionViewItem *option,
                          const QModelIndex &index) const;

     /**
      * @brief Retrieves the FileInfo object associated with a given model index
      * @param index The QModelIndex for which to retrieve the FileInfo
      * @return std::shared_ptr<FileInfo> The FileInfo object, or nullptr if not found
      */
     std::shared_ptr<FileInfo> getFileInfo(const QModelIndex &index) const;

protected:
    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;

    //edit
    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
    void setEditorData(QWidget *editor, const QModelIndex &index) const override;
    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;

private Q_SLOT:
    void slot_finishEdit();/* 编辑完成 */

private:
    QPushButton *m_styled_button;
};

}

#endif // DESKTOPICONVIEWDELEGATE_H
